@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef RESOURCES_H
-#define RESOURCES_H
+#pragma once
 
 // Qt
 #include <QString>
@@ -66,5 +65,3 @@ Q_SIGNALS:
 private:
     D_PTR;
 };
-
-#endif // RESOURCES_H
